@@ -238,9 +238,9 @@ def _out_of_flow_layout(context, box, index, child, new_children,
             context, child, box, absolute_boxes, fixed_boxes, bottom_space,
             skip_stack=None)
         # New page if overflow
-        if (page_is_empty and not new_children) or not (
-                new_child.position_y + new_child.height >
-                context.page_bottom - bottom_space):
+        page_overflow = context.overflows_page(
+            bottom_space, new_child.position_y + new_child.height)
+        if (page_is_empty and not new_children) or not page_overflow:
             new_child.index = index
             new_children.append(new_child)
         else:
@@ -318,7 +318,7 @@ def _linebox_layout(context, box, index, child, new_children, page_is_empty,
         # page and can advance in the context.
         overflow = (
             (new_children or not page_is_empty) and
-            (new_position_y + offset_y > context.page_bottom - bottom_space))
+            context.overflows_page(bottom_space, new_position_y + offset_y))
         if overflow:
             abort, stop, resume_at = _break_line(
                 box, new_children, lines_iterator, page_is_empty, index,
@@ -330,8 +330,8 @@ def _linebox_layout(context, box, index, child, new_children, page_is_empty,
         # "When an unforced page break occurs here, both the adjoining
         #  ‘margin-top’ and ‘margin-bottom’ are set to zero."
         # See https://github.com/Kozea/WeasyPrint/issues/115
-        elif page_is_empty and (
-                new_position_y > context.page_bottom - bottom_space):
+        elif page_is_empty and context.overflows_page(
+                bottom_space, new_position_y):
             # Remove the top border when a page is empty and the box is
             # too high to be drawn in one page
             new_position_y -= box.margin_top
@@ -345,9 +345,10 @@ def _linebox_layout(context, box, index, child, new_children, page_is_empty,
                 if descendant.footnote in context.footnotes)
             for footnote in footnotes:
                 context.layout_footnote(footnote)
-                overflow = context.reported_footnotes or (
-                    new_position_y + offset_y >
-                    context.page_bottom - bottom_space)
+                overflow = (
+                    context.reported_footnotes or
+                    context.overflows_page(
+                        bottom_space, new_position_y + offset_y))
                 if overflow:
                     context.report_footnote(footnote)
                     if footnote.style['footnote_policy'] == 'line':
@@ -451,10 +452,6 @@ def _in_flow_layout(context, box, index, child, new_children, page_is_empty,
          fixed_boxes, adjoining_margins, discard)
 
     if new_child is not None:
-        # index in its non-laid-out parent, not in future new parent
-        # May be used in find_earlier_page_break()
-        new_child.index = index
-
         # We need to do this after the child layout to have the
         # used value for margin_top (eg. it might be a percentage.)
         if not isinstance(new_child, (boxes.BlockBox, boxes.TableBox)):
@@ -469,15 +466,15 @@ def _in_flow_layout(context, box, index, child, new_children, page_is_empty,
                 new_child.content_box_y() + new_child.height)
             new_position_y = (
                 new_child.border_box_y() + new_child.border_height())
-
-            if (new_content_position_y > context.page_bottom - bottom_space and
-                    not page_is_empty_with_no_children):
+            page_overflow = context.overflows_page(
+                bottom_space, new_content_position_y)
+            if page_overflow and not page_is_empty_with_no_children:
                 # The child content overflows the page area, display it on the
                 # next page.
                 remove_placeholders([new_child], absolute_boxes, fixed_boxes)
                 new_child = None
-            elif (new_position_y > context.page_bottom - bottom_space and
-                    not page_is_empty_with_no_children):
+            elif not page_is_empty_with_no_children and context.overflows_page(
+                    bottom_space, new_position_y):
                 # The child border/padding overflows the page area, do the
                 # layout again with a higher bottom_space value.
                 remove_placeholders([new_child], absolute_boxes, fixed_boxes)
@@ -545,6 +542,9 @@ def _in_flow_layout(context, box, index, child, new_children, page_is_empty,
             abort, stop, resume_at, position_y, adjoining_margins, next_page,
             new_children)
 
+    # index in its non-laid-out parent, not in future new parent
+    # May be used in find_earlier_page_break()
+    new_child.index = index
     new_children.append(new_child)
     if resume_at is not None:
         resume_at = {index: resume_at}
